@@ -336,7 +336,7 @@ class SpriteCSS(object):
         }
     """
 
-    def __init__(self, id, width, height, spritesheet, time, steps, loop=True, y_offset=0, bg_color="none"):
+    def __init__(self, id: str, width: int, height: int, spritesheet: str, time, steps: int, loop: bool=True, y_offset: int=0, bg_color: str="none"):
         self.id = id
         self.styles = SpriteCSS.STYLE(id, width, height, spritesheet, time, steps, loop, y_offset, bg_color)
 
@@ -366,13 +366,20 @@ class DomonicJS(object):
 
     def __str__(self):
         return script("""
-            window.domonic = {'version':'0.0.2'}; // || domonic.js
+            window.domonic = {'version':'0.0.3'}; // || domonic.js
             function print(msg){
                 console.log(msg);
             }
             function title(str){
                 return str.charAt(0).toUpper();
             }
+            function* enumerate(it, start = 0) {
+                // i.e. for (const [value, index] of enumerate(word)) {
+                let index = start;
+                for (const value of it) {
+                    yield [value, index++];
+                }
+            }
             //class list() {
             //    constructor(list) {
             //        this.list = list;
