@@ -6,21 +6,24 @@
 import copy
 from domonic.javascript import URL
 from domonic.dom import Node, Element, Document, DocumentType, Comment, Text
+from domonic.dom import (HTMLDialogElement)
+
+
 
 html_tags = [
             "figcaption", "blockquote", "textarea", "progress", "optgroup", "noscript", "fieldset", "datalist",
             "colgroup", "summary", "section", "details", "command", "caption", "article", "address", "submit",
-            "strong", "source", "select", "script", "output", "option", "object", "legend", "keygen", "iframe",
-            "hgroup", "header", "footer", "figure", "canvas", "button", "video", "track", "title", "title",
-            "thead", "tfoot", "tbody", "table", "style", "small", "param", "meter", "label", "input", "embed",
-            "audio", "aside", "time", "span", "span", "samp", "ruby", "meta", "meta", "menu", "mark", "link",
-            "applet", "object", "basefont", "center", "dir", "embed", "font", "isindex", "listing", "menuitem",
-            "plaintext", "pre", "strike", "xmp", "template", "picture",
+            "strong", "source", "select", "script", "output", "option", "legend", "keygen", "iframe",
+            "hgroup", "header", "footer", "figure", "canvas", "button", "video", "track", "title",
+            "thead", "tfoot", "tbody", "table", "style", "small", "param", "meter", "label", "input",
+            "audio", "aside", "time", "span", "samp", "ruby", "meta", "menu", "mark", "link",
+            "applet", "object", "basefont", "center", "dir", "embed", "isindex", "listing", "menuitem",
+            "plaintext", "pre", "strike", "xmp", "template", "picture", "dialog"
             "html", "head", "form", "font", "code", "cite", "body", "base", "area", "abbr", "wbr", "var", "sup",
-            "sub", "pre", "nav", "map", "main", "kbd", "ins", "img", "div", "dfn", "del", "col", "bdo", "bdi",
-            "ul", "tr", "th", "td", "rt", "rp", "ol", "li", "hr", "hr", "h6", "h5", "h4", "h3", "h2", "h1",
+            "sub", "nav", "map", "main", "kbd", "ins", "img", "div", "dfn", "del", "col", "bdo", "bdi",
+            "ul", "tr", "th", "td", "rt", "rp", "ol", "li", "hr", "h6", "h5", "h4", "h3", "h2", "h1",
             "em", "dt", "dl", "dd", "br", "u", "s", "q", "p", "i", "b", "a"]
-            # big, small, blink, bold, strong, em, i, u, s, strike, tt, code, kbd, samp, var,
+            # big, blink, bold, tt, var,
 
 html_attributes = [
             "accept", "accesskey", "action", "align", "alt", "async", "autocomplete", "autofocus",
@@ -154,7 +157,7 @@ class tag(object):
             key = key.split('_', 1)[1]
             # lets us have boolean attributes  # TODO - should be optional by a global config
             if key in ['async', 'checked', 'autofocus', 'disabled', 'formnovalidate', 'hidden', 'multiple',
-                       'novalidate', 'readonly', 'required', 'selected']:
+                       'novalidate', 'readonly', 'required', 'selected', "open"]:
                 if value == '' or value == key:
                     return ''' %s''' % key
             return ''' %s="%s"''' % (key, value)
@@ -617,7 +620,6 @@ hr = type('hr', (closed_tag, Element), {'name': 'hr', '__init__': tag_init})
 br = type('br', (closed_tag, Element), {'name': 'br', '__init__': tag_init})
 wbr = type('wbr', (closed_tag, Element), {'name': 'wbr', '__init__': tag_init})
 img = type('img', (closed_tag, Element), {'name': 'img', '__init__': tag_init})
-embed = type('embed', (closed_tag, Element), {'name': 'embed', '__init__': tag_init})
 param = type('param', (closed_tag, Element), {'name': 'param', '__init__': tag_init})
 source = type('source', (closed_tag, Element), {'name': 'source', '__init__': tag_init})
 track = type('track', (closed_tag, Element), {'name': 'track', '__init__': tag_init})
@@ -635,12 +637,9 @@ basefont = type('basefont', (tag, Element), {'name': 'basefont', '__init__': tag
 center = type('center', (tag, Element), {'name': 'center', '__init__': tag_init})
 # dir = type('dir', (tag, Element), {'name': 'dir', '__init__': tag_init})
 embed = type('embed', (tag, Element), {'name': 'embed', '__init__': tag_init})
-font = type('font', (tag, Element), {'name': 'font', '__init__': tag_init})
 isindex = type('isindex', (tag, Element), {'name': 'isindex', '__init__': tag_init})
 listing = type('listing', (tag, Element), {'name': 'listing', '__init__': tag_init})
-# menu = type('menu', (tag, Element), {'name': 'menu', '__init__': tag_init})
 plaintext = type('plaintext', (tag, Element), {'name': 'plaintext', '__init__': tag_init})
-pre = type('pre', (tag, Element), {'name': 'pre', '__init__': tag_init})
 s = type('s', (tag, Element), {'name': 's', '__init__': tag_init})
 u = type('u', (tag, Element), {'name': 'u', '__init__': tag_init})
 strike = type('strike', (tag, Element), {'name': 'strike', '__init__': tag_init})
@@ -648,7 +647,8 @@ xmp = type('xmp', (tag, Element), {'name': 'xmp', '__init__': tag_init})
 
 template = type('template', (tag, Element), {'name': 'template', '__init__': tag_init})
 picture = type('picture', (tag, Element), {'name': 'picture', '__init__': tag_init})
-
+dialog = type('dialog', (tag, HTMLDialogElement), {'name': 'dialog', '__init__': tag_init})
+# dialog = HTMLDialogElement  # TODO - might get rid of tag and put all its methods on Node directly
 
 # legacy.
 doctype = DocumentType
