@@ -6,8 +6,7 @@
 
 """
 
-
-from .encoding import *
-from .fetch import *
-
-from .url import *
\ No newline at end of file
+# DONT DO THIS...
+# from .encoding import *
+# from .fetch import *
+# from .url import *
